import * as THREE from 'three';
import { useEffect } from 'react';
import { upsertProductOrEventApi } from '../../../../services/simulation/products/UpsertProductOrEventApi';
import { getAllProductsApi } from '../../../../services/simulation/products/getallProductsApi';
import { usePlayButtonStore, useResetButtonStore } from '../../../../store/usePlayButtonStore';
import { useSceneContext } from '../../../scene/sceneContext';
import { useProductContext } from '../../../simulation/products/productContext';
import { useComparisonProduct } from '../../../../store/simulation/useSimulationStore';
import { useDuplicateProductStore } from '../../duplicateStores/duplicateProductStore';

function ProductsDuplicate({ projectId }: { projectId: string }) {
    const { armBotStore, machineStore, conveyorStore, vehicleStore, storageUnitStore, layout } = useSceneContext();
    const { products, getProductById, setProducts } = useDuplicateProductStore();
    const { selectedProductStore } = useProductContext();
    const { selectedProduct, setSelectedProduct } = selectedProductStore();
    const { addVehicle, clearvehicles } = vehicleStore();
    const { addArmBot, clearArmBots } = armBotStore();
    const { addMachine, clearMachines } = machineStore();
    const { addConveyor, clearConveyors } = conveyorStore();
    const { setCurrentMaterials, clearStorageUnits, updateCurrentLoad, addStorageUnit } = storageUnitStore();
    const { isReset } = useResetButtonStore();
    const { isPlaying } = usePlayButtonStore();
    const { comparisonProduct } = useComparisonProduct();

    useEffect(() => {
        if (layout === 'Comparison Layout' && comparisonProduct) {
            setSelectedProduct(comparisonProduct.productUuid, comparisonProduct.productName);
        }
    }, [comparisonProduct])

    useEffect(() => {
        getAllProductsApi(projectId || '').then((data) => {
            if (data.length > 0)  {
                setProducts(data);
            }
        })
    }, [])

    useEffect(() => {
        if (selectedProduct.productUuid) {
            const product = getProductById(selectedProduct.productUuid);
            if (product) {
                clearvehicles();
                product.eventDatas.forEach(events => {
                    if (events.type === 'vehicle') {
                        addVehicle(selectedProduct.productUuid, events);
                    }
                });
            }
        }
    }, [selectedProduct, products, isReset, isPlaying]);

    useEffect(() => {
        if (selectedProduct.productUuid) {
            const product = getProductById(selectedProduct.productUuid);
            if (product) {
                clearArmBots();
                product.eventDatas.forEach(events => {
                    if (events.type === 'roboticArm') {
                        addArmBot(selectedProduct.productUuid, events);
                    }
                });
            }
        }
    }, [selectedProduct, products, isReset, isPlaying]);

    useEffect(() => {
        if (selectedProduct.productUuid) {
            const product = getProductById(selectedProduct.productUuid);
            if (product) {
                clearConveyors();
                product.eventDatas.forEach(events => {
                    if (events.type === 'transfer') {
                        addConveyor(selectedProduct.productUuid, events);
                    }
                });
            }
        }
    }, [selectedProduct, products, isReset, isPlaying]);

    useEffect(() => {
        if (selectedProduct.productUuid) {
            const product = getProductById(selectedProduct.productUuid);
            if (product) {
                clearMachines();
                product.eventDatas.forEach(events => {
                    if (events.type === 'machine') {
                        addMachine(selectedProduct.productUuid, events);
                    }
                });
            }
        }
    }, [selectedProduct, products, isReset, isPlaying]);

    useEffect(() => {
        if (selectedProduct.productUuid) {
            const product = getProductById(selectedProduct.productUuid);
            if (product) {
                clearStorageUnits();
                product.eventDatas.forEach(event => {
                    if (event.type === 'storageUnit') {
                        addStorageUnit(selectedProduct.productUuid, event);

                        if (event.point.action.actionType === 'retrieve') {
                            const storageAction = event.point.action;
                            const materials = Array.from({ length: storageAction.storageCapacity }, () => ({
                                materialType: storageAction.materialType || 'Default material',
                                materialId: THREE.MathUtils.generateUUID()
                            }));

                            setCurrentMaterials(event.modelUuid, materials);
                            updateCurrentLoad(event.modelUuid, storageAction.storageCapacity);
                        } else {
                            setCurrentMaterials(event.modelUuid, []);
                            updateCurrentLoad(event.modelUuid, 0);
                        }
                    }
                });
            }
        }
    }, [selectedProduct, products, isReset, isPlaying]);

    return (
        <>

        </>
    )
}

export default ProductsDuplicate